summaryrefslogtreecommitdiff
path: root/libavformat/aviobuf.c
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-03-17 08:13:34 +0100
committerAnton Khirnov <anton@khirnov.net>2011-04-03 22:46:56 +0200
commitb92c5452822f9f58d33daf933a0d2a5516866bc1 (patch)
tree8e837202fc801d8f0de5e8be08b691a7d357cde9 /libavformat/aviobuf.c
parent8978fedaeefdff50ed4deefbfe822ad07f19f616 (diff)
avio: avio_ prefix for url_open_dyn_buf
Diffstat (limited to 'libavformat/aviobuf.c')
-rw-r--r--libavformat/aviobuf.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/libavformat/aviobuf.c b/libavformat/aviobuf.c
index dd997d73e2..53fce9e724 100644
--- a/libavformat/aviobuf.c
+++ b/libavformat/aviobuf.c
@@ -419,6 +419,10 @@ unsigned long get_checksum(AVIOContext *s)
{
return ffio_get_checksum(s);
}
+int url_open_dyn_buf(AVIOContext **s)
+{
+ return avio_open_dyn_buf(s);
+}
#endif
int avio_put_str(AVIOContext *s, const char *str)
@@ -1023,7 +1027,7 @@ int64_t ffio_read_seek(AVIOContext *s, int stream_index,
return ret;
}
/* url_open_dyn_buf and url_close_dyn_buf are used in rtp.c to send a response
* back to the server even if CONFIG_MUXERS is false. */
#if CONFIG_MUXERS || CONFIG_NETWORK
/* buffer handling */
@@ -1147,7 +1151,7 @@ static int url_open_dyn_buf_internal(AVIOContext **s, int max_packet_size)
return ret;
}
-int url_open_dyn_buf(AVIOContext **s)
+int avio_open_dyn_buf(AVIOContext **s)
{
return url_open_dyn_buf_internal(s, 0);
}
@@ -1023,7 +1027,7 @@ int64_t ffio_read_seek(AVIOContext *s, int stream_index,
return ret;
}
-/* url_open_dyn_buf and url_close_dyn_buf are used in rtp.c to send a response
+/* avio_open_dyn_buf and url_close_dyn_buf are used in rtp.c to send a response
* back to the server even if CONFIG_MUXERS is false. */
#if CONFIG_MUXERS || CONFIG_NETWORK